Clazz.declarePackage("J.quantum.mo");
Clazz.declareInterface(J.quantum.mo, "DataAdder");
;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
